" Maintainer:	Peter Valach <pvalach@gmx.net>
" Last Changed: 2002 Feb 3
" URL:		http://www.pv2c.sk/free/sk_vimkeymap/

let b:keymap_name = "sk"

loadkeymap
" Z a Y - ak chcete slovensku qwerty, zakomentujte tieto styri riadky
y z
z y
Y Z
Z Y

" Horny riadok
` ;
1 +
! 1
2 µ
@ 2
3 ¹
# 3
4 è
$ 4
5 »
% 5
6 ¾
^ 6
7 ý
& 7
8 á
* 8
9 í
( 9
0 é
) 0
- =
_ %

" Klavesy okolo Enteru :)
[ ú
{ /
] ä
} (
\\ ò
<Bar> )
; ô
: "
' §
\" !
", , ;-)
< ?
". . ;-)
> :
/ -
? _

" Dlzne
=a á
=A Á
=e é
=E É
=i í
=I Í
=l å
=L Å
=o ó
=O Ó
=r à
=R À
=u ú
=U Ú
=z ý
=Z Ý
" pre pripad omylu :) alebo slovenskej QWERTY
=y ý
=Y Ý

" Makcene
+a ä
+A Ä
+c è
+C È
+d ï
+D Ï
+l µ
+L ¥
+n ò
+N Ò
+o ô
+O Ô
+s ¹
+S ©
+t »
+T «
+y ¾
+Y ®
" pre pripad omylu :) alebo slovenskej QWERTY
+z ¾
+Z ®

